@@ -23,6 +23,10 @@ func (u *UnmanagedSecurityGroupRulesAlert) ShouldIgnoreResource() bool {
 	return false
 }
 
+func (u *UnmanagedSecurityGroupRulesAlert) Resource() *resource.Resource {
+	return nil
+}
+
 type ComputedDiffAlert struct{}
 
 func NewComputedDiffAlert() *ComputedDiffAlert {
@@ -37,6 +41,10 @@ func (c *ComputedDiffAlert) ShouldIgnoreResource() bool {
 	return false
 }
 
+func (c *ComputedDiffAlert) Resource() *resource.Resource {
+	return nil
+}
+
 type AnalyzerOptions struct {
 	Deep          bool `json:"deep"`
 	OnlyManaged   bool `json:"only_managed"`
